@@ -4,6 +4,9 @@ from local_tuya.domoticz.units import (
     Unit,
     UnitId,
     UnitManager,
+    compose,
+    debounce,
+    moving_average,
     selector_switch_unit,
     set_point_unit,
     switch_unit,
