@@ -1,14 +1,13 @@
 import logging
-from contextlib import AsyncExitStack
 from typing import Callable, Dict, Generic, Optional, Type, TypeVar
 
-from concurrent_tasks import BlockingThreadedTaskPool
+from concurrent_tasks import BlockingThreadedTaskPool, ThreadedPoolContextManagerWrapper
 
 from local_tuya.device import Device, State
 from local_tuya.domoticz.logger import DomoticzHandler
 from local_tuya.domoticz.types import DomoticzDevice
 from local_tuya.domoticz.units import UnitCommand, UnitId, UnitManager
-from local_tuya.protocol import ProtocolConfig
+from local_tuya.protocol import ProtocolConfig, Version
 
 try:
     import DomoticzEx
@@ -22,21 +21,6 @@ T = TypeVar("T", bound=State)
 OnStart = Callable[[ProtocolConfig, Dict[str, str], UnitManager[T]], Device[T]]
 
 
-class DeviceContextManager(AsyncExitStack):
-    """To make devices work they need to be initialized in the task pool
-    so that all asyncio primitives are attached to the right event loop.
-    """
-
-    def __init__(self, get_device: Callable[[], Device]):
-        super().__init__()
-        self._get_device = get_device
-        self._device: Optional[Device] = None
-
-    async def __aenter__(self):
-        self._device = await self.enter_async_context(self._get_device())
-        return self
-
-
 class Plugin(Generic[T]):
     """Defines the Domoticz plugin.
     It connects the device to Domoticz units.
@@ -46,8 +30,9 @@ class Plugin(Generic[T]):
         self,
         package: str,
         on_start: OnStart,
-        unit_ids: Optional[Type[UnitId]] = None,
+        unit_ids: Optional[Type[UnitId]],
     ):
+        self._package = package
         self._on_start = on_start
         self._unit_ids = unit_ids
         self._manager: Optional[UnitManager[T]] = None
@@ -56,7 +41,6 @@ class Plugin(Generic[T]):
         for pkg in ("local_tuya", package):
             _logger = logging.getLogger(pkg)
             _logger.addHandler(LOG_HANDLER)
-            _logger.setLevel(logging.DEBUG)
 
     @staticmethod
     def _protocol_config(parameters: Dict[str, str]) -> ProtocolConfig:
@@ -65,8 +49,16 @@ class Plugin(Generic[T]):
             address=parameters["Address"],
             port=int(parameters["Port"]),
             key=parameters["Password"].encode(),
+            version=Version(parameters["Mode4"].encode()),
         )
 
+    def _setup_logging(self, debug: bool) -> None:
+        DomoticzEx.Debugging(2 + 4 + 8 if debug else 0)
+        # Setup loggers to log in Domoticz.
+        for pkg in ("local_tuya", self._package):
+            _logger = logging.getLogger(pkg)
+            _logger.setLevel(logging.DEBUG if debug else logging.INFO)
+
     def start(
         self,
         parameters: Dict[str, str],
@@ -74,8 +66,8 @@ class Plugin(Generic[T]):
     ) -> None:
         """Start the device in a separate thread."""
         self.stop()
+        self._setup_logging(parameters.get("Mode6", "") == "1")
         DomoticzEx.Heartbeat(15)
-        DomoticzEx.Debugging(2 + 4 + 8 if parameters.get("Mode6", "") == "1" else 4)
         name = parameters["Name"]
         included_units = parameters.get("Mode5", "")
         manager: UnitManager[T] = UnitManager(
@@ -95,7 +87,7 @@ class Plugin(Generic[T]):
             return device
 
         self._task_pool = BlockingThreadedTaskPool(
-            context_manager=DeviceContextManager(_get_device)
+            context_manager=ThreadedPoolContextManagerWrapper(_get_device),
         )
         self._task_pool.start()
 
@@ -104,7 +96,9 @@ class Plugin(Generic[T]):
         if self._task_pool:
             self._task_pool.stop()
             self._task_pool = None
-        self._manager = None
+        if self._manager:
+            self._manager.cleanup_domoticz_references()
+            self._manager = None
 
     def on_command(self, unit_id: int, command: UnitCommand) -> None:
         """Send an command to the device asynchronously."""
